﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Threading;

using BindingListDemoConsole;
using Infragistics.Win.UltraWinGrid;

namespace BindingListDemoUI
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            BindingList<CollectionMember> list = CollectionManager.Instance.GetList();
            ultraGrid1.DataSource = list;

            ultraGrid1.DisplayLayout.Override.SummaryDisplayArea = SummaryDisplayAreas.BottomFixed | SummaryDisplayAreas.InGroupByRows | SummaryDisplayAreas.RootRowsFootersOnly;
            ultraGrid1.DisplayLayout.Override.GroupBySummaryDisplayStyle = GroupBySummaryDisplayStyle.SummaryCells;
            ultraGrid1.DisplayLayout.Override.SummaryFooterCaptionVisible = Infragistics.Win.DefaultableBoolean.False;
            ultraGrid1.DisplayLayout.Override.FilterUIType = FilterUIType.FilterRow;
            ultraGrid1.DisplayLayout.Override.FilterClearButtonLocation = FilterClearButtonLocation.RowAndCell;
            ultraGrid1.DisplayLayout.Override.RowSelectorHeaderStyle = RowSelectorHeaderStyle.ColumnChooserButton;
            ultraGrid1.DisplayLayout.Override.RowSelectors = Infragistics.Win.DefaultableBoolean.True;
            ultraGrid1.DisplayLayout.Override.HeaderPlacement = HeaderPlacement.FixedOnTop;
            ultraGrid1.DisplayLayout.LoadStyle = LoadStyle.LoadOnDemand;
            ultraGrid1.DisplayLayout.ViewStyleBand = ViewStyleBand.OutlookGroupBy;
            ultraGrid1.DisplayLayout.ColumnChooserEnabled = Infragistics.Win.DefaultableBoolean.True;

            ultraGrid1.InitializeRow += new InitializeRowEventHandler(ultraGrid1_InitializeRow);
            UltraGridBand b = ultraGrid1.DisplayLayout.Bands[0];
            foreach (UltraGridColumn c in b.Columns)
            {
                c.Format = "#,##0;(#,##0);0";
                c.Style = Infragistics.Win.UltraWinGrid.ColumnStyle.Double;
                c.CellDisplayStyle = CellDisplayStyle.FormattedText;
                if (c.DataType == typeof(decimal))
                {
                    b.Summaries.Add(c.Key, SummaryType.Sum, c);
                }
            }

            //start up the collection manager
            CollectionManager cManager = CollectionManager.Instance;

            Thread _changeCollectionThread = new Thread(ChangeCollectionValues);
            _changeCollectionThread.Name = "Check for last message received";
            _changeCollectionThread.Priority = ThreadPriority.Normal;
            _changeCollectionThread.IsBackground = true;
            _changeCollectionThread.Start();
            Thread.Sleep(10);
            Thread _addCollectionThread = new Thread(AddCollectionMembers);
            _addCollectionThread.Name = "Add members";
            _addCollectionThread.Priority = ThreadPriority.Normal;
            _addCollectionThread.IsBackground = true;
            _addCollectionThread.Start();
        }

        void ultraGrid1_InitializeRow(object sender, InitializeRowEventArgs e)
        {
            if (e.ReInitialize)
            {
                e.Row.RefreshSortPosition();
                e.Row.RefreshFilters();
            }
        }

        private void ChangeCollectionValues()
        {
            Random r = new Random();
            BindingList<CollectionMember> list = CollectionManager.Instance.GetList();
            while (true)
            {
                Thread.Sleep(200);
                this.BeginInvoke((MethodInvoker)delegate
                {
                    //Randomly Change the values in the thread.
                    for (int i = 0; i < 250; i++)
                    {
                        list[r.Next(0, CollectionManager.Instance.Count)].ChangeValues();
                    }
                });
            }
        }

        private void AddCollectionMembers()
        {
            Random r = new Random();
            while (true)
            {
                Thread.Sleep(500);

                this.BeginInvoke((MethodInvoker)delegate
                {
                    CollectionManager.Instance.AddMember(r);
                });
            }
        }
    }
}
